source("http://callr.org/install#knitr") ## to build package vignette
source("http://callr.org/install#R.utils")
install.packages("geometry")

## for SuperLearning
install.packages("SuperLearner")
install.packages("gam")
install.packages("glmnet")
install.packages("nnls")
install.packages("e1071")
install.packages("polspline")
install.packages("quadprog")
install.packages("randomForest")

